@@ -4,7 +4,7 @@ Attean - A Semantic Web Framework
 
 =head1 VERSION
 
-This document describes Attean version 0.033_02	
+This document describes Attean version 0.034_01	
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Semantic Web (RDF and SPARQL) data.
 package Attean {
 	use v5.14;
 	use warnings;
-	our $VERSION	= '0.033_02';
+	our $VERSION	= '0.034_01';
 	use Attean::API;
 	
 	use Attean::Blank;
@@ -76,7 +76,7 @@ package Attean {
 	use Attean::TermMap;
 	
 	use HTTP::Negotiate qw(choose);
-	use List::MoreUtils qw(any all);
+	use List::Util qw(any all);
 	use Module::Load::Conditional qw(can_load);
 	use Role::Tiny ();
 	use Sub::Util qw(set_subname);
