@@ -7,7 +7,7 @@ Attean::API::Query - Utility package defining query-related roles
 
 =head1 VERSION
 
-This document describes Attean::API::Query version 0.031
+This document describes Attean::API::Query version 0.034
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ This is a utility package for defining query-related roles:
 
 =cut
 
-package Attean::API::DirectedAcyclicGraph 0.031 {
+package Attean::API::DirectedAcyclicGraph 0.034 {
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(ArrayRef ConsumerOf);
 
@@ -149,7 +149,7 @@ package Attean::API::DirectedAcyclicGraph 0.031 {
 	}
 }
 
-package Attean::API::SPARQLSerializable 0.031 {
+package Attean::API::SPARQLSerializable 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Encode qw(decode_utf8);
@@ -166,7 +166,8 @@ package Attean::API::SPARQLSerializable 0.031 {
 		my $s		= AtteanX::Serializer::SPARQL->new();
 		my $i		= $self->sparql_tokens;
 		my $bytes	= $s->serialize_iter_to_bytes($i);
-		return decode_utf8($bytes);
+		my $sparql	= decode_utf8($bytes);
+		return $sparql
 	}
 	
 	sub sparql_subtokens {
@@ -261,6 +262,9 @@ package Attean::API::SPARQLSerializable 0.031 {
 					push(@tokens, $v->sparql_tokens->elements);
 					push(@tokens, $rparen);
 					$modifiers{project_expression_tokens}{$name}	= \@tokens;
+					unless ($modifiers{project_variables}{$name}++) {
+						unshift(@{ $modifiers{project_variables_order} }, $v->value);
+					}
 				} elsif ($algebra->isa('Attean::Algebra::Project')) {
 					my $vars	= $algebra->variables;
 					my ($child)	= @{ $algebra->children };
@@ -402,7 +406,7 @@ package Attean::API::SPARQLSerializable 0.031 {
 	}
 }
 
-package Attean::API::SPARQLQuerySerializable 0.031 {
+package Attean::API::SPARQLQuerySerializable 0.034 {
 	use Moo::Role;
 	use namespace::clean;
 	with 'Attean::API::SPARQLSerializable';
@@ -417,7 +421,7 @@ package Attean::API::SPARQLQuerySerializable 0.031 {
 
 =cut
 
-package Attean::API::Algebra 0.031 {
+package Attean::API::Algebra 0.034 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	
@@ -496,7 +500,7 @@ package Attean::API::Algebra 0.031 {
 
 =cut
 
-package Attean::API::QueryTree 0.031 {
+package Attean::API::QueryTree 0.034 {
 	use Moo::Role;
 	with 'Attean::API::DirectedAcyclicGraph';
 }
@@ -505,7 +509,7 @@ package Attean::API::QueryTree 0.031 {
 
 =cut
 
-package Attean::API::NullaryQueryTree 0.031 {
+package Attean::API::NullaryQueryTree 0.034 {
 	use Moo::Role;
 	sub arity { return 0 }
 	with 'Attean::API::QueryTree';
@@ -515,7 +519,7 @@ package Attean::API::NullaryQueryTree 0.031 {
 
 =cut
 
-package Attean::API::UnaryQueryTree 0.031 {
+package Attean::API::UnaryQueryTree 0.034 {
 	use Moo::Role;
 	sub arity { return 1 }
 	with 'Attean::API::QueryTree';
@@ -530,7 +534,7 @@ package Attean::API::UnaryQueryTree 0.031 {
 
 =cut
 
-package Attean::API::BinaryQueryTree 0.031 {
+package Attean::API::BinaryQueryTree 0.034 {
 	use Moo::Role;
 	sub arity { return 2 }
 	with 'Attean::API::QueryTree';
@@ -540,7 +544,7 @@ package Attean::API::BinaryQueryTree 0.031 {
 
 =cut
 
-package Attean::API::PropertyPath 0.031 {
+package Attean::API::PropertyPath 0.034 {
 	use Moo::Role;
 	with 'Attean::API::QueryTree';
 	requires 'as_string';
@@ -551,7 +555,7 @@ package Attean::API::PropertyPath 0.031 {
 
 =cut
 
-package Attean::API::UnaryPropertyPath 0.031 {
+package Attean::API::UnaryPropertyPath 0.034 {
 	use Types::Standard qw(ConsumerOf);
 
 	use Moo::Role;
@@ -581,7 +585,7 @@ package Attean::API::UnaryPropertyPath 0.031 {
 
 =cut
 
-package Attean::API::NaryPropertyPath 0.031 {
+package Attean::API::NaryPropertyPath 0.034 {
 	use Types::Standard qw(ArrayRef ConsumerOf);
 
 	use Moo::Role;
@@ -608,7 +612,7 @@ package Attean::API::NaryPropertyPath 0.031 {
 
 =cut
 
-package Attean::API::UnionScopeVariables 0.031 {
+package Attean::API::UnionScopeVariables 0.034 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
@@ -624,7 +628,7 @@ package Attean::API::UnionScopeVariables 0.031 {
 
 =cut
 
-package Attean::API::IntersectionScopeVariables 0.031 {
+package Attean::API::IntersectionScopeVariables 0.034 {
 	use Moo::Role;
 	sub in_scope_variables {
 		my $self	= shift;
