@@ -8,7 +8,7 @@ Attean::Algebra - Representation of SPARQL algebra operators
 
 =head1 VERSION
 
-This document describes Attean::Algebra version 0.033
+This document describes Attean::Algebra version 0.034
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ in the Attean::Algebra namespace:
 
 use Attean::API::Query;
 
-package Attean::Algebra::Query 0.033 {
+package Attean::Algebra::Query 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Types::Standard qw(Bool ArrayRef HashRef ConsumerOf);
@@ -120,7 +120,7 @@ package Attean::Algebra::Query 0.033 {
 	}
 }
 
-package Attean::Algebra::Update 0.033 {
+package Attean::Algebra::Update 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Types::Standard qw(Bool);
@@ -142,7 +142,7 @@ package Attean::Algebra::Update 0.033 {
 
 =cut
 
-package Attean::Algebra::Sequence 0.033 {
+package Attean::Algebra::Sequence 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -175,7 +175,7 @@ package Attean::Algebra::Sequence 0.033 {
 
 =cut
 
-package Attean::Algebra::Join 0.033 {
+package Attean::Algebra::Join 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -204,7 +204,7 @@ package Attean::Algebra::Join 0.033 {
 
 =cut
 
-package Attean::Algebra::LeftJoin 0.033 {
+package Attean::Algebra::LeftJoin 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -261,7 +261,7 @@ package Attean::Algebra::LeftJoin 0.033 {
 
 =cut
 
-package Attean::Algebra::Filter 0.033 {
+package Attean::Algebra::Filter 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -297,7 +297,7 @@ package Attean::Algebra::Filter 0.033 {
 
 =cut
 
-package Attean::Algebra::Union 0.033 {
+package Attean::Algebra::Union 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -328,7 +328,7 @@ package Attean::Algebra::Union 0.033 {
 
 =cut
 
-package Attean::Algebra::Graph 0.033 {
+package Attean::Algebra::Graph 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -376,7 +376,7 @@ package Attean::Algebra::Graph 0.033 {
 
 =cut
 
-package Attean::Algebra::Extend 0.033 {
+package Attean::Algebra::Extend 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -482,7 +482,7 @@ package Attean::Algebra::Unfold 0.031 {
 
 =cut
 
-package Attean::Algebra::Minus 0.033 {
+package Attean::Algebra::Minus 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -520,7 +520,7 @@ package Attean::Algebra::Minus 0.033 {
 
 =cut
 
-package Attean::Algebra::Distinct 0.033 {
+package Attean::Algebra::Distinct 0.034 {
 	use Moo;
 	use namespace::clean;
 
@@ -534,7 +534,7 @@ package Attean::Algebra::Distinct 0.033 {
 
 =cut
 
-package Attean::Algebra::Reduced 0.033 {
+package Attean::Algebra::Reduced 0.034 {
 	use Moo;
 	use namespace::clean;
 
@@ -548,7 +548,7 @@ package Attean::Algebra::Reduced 0.033 {
 
 =cut
 
-package Attean::Algebra::Slice 0.033 {
+package Attean::Algebra::Slice 0.034 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -571,7 +571,7 @@ package Attean::Algebra::Slice 0.033 {
 
 =cut
 
-package Attean::Algebra::Project 0.033 {
+package Attean::Algebra::Project 0.034 {
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use Moo;
 	use namespace::clean;
@@ -599,7 +599,7 @@ package Attean::Algebra::Project 0.033 {
 
 =cut
 
-package Attean::Algebra::Comparator 0.033 {
+package Attean::Algebra::Comparator 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -643,7 +643,7 @@ package Attean::Algebra::Comparator 0.033 {
 
 =cut
 
-package Attean::Algebra::OrderBy 0.033 {
+package Attean::Algebra::OrderBy 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -666,7 +666,7 @@ package Attean::Algebra::OrderBy 0.033 {
 
 =cut
 
-package Attean::Algebra::BGP 0.033 {
+package Attean::Algebra::BGP 0.034 {
 	use Moo;
 	use Attean::RDF;
 	use Set::Scalar;
@@ -736,7 +736,7 @@ package Attean::Algebra::BGP 0.033 {
 
 =cut
 
-package Attean::Algebra::Service 0.033 {
+package Attean::Algebra::Service 0.034 {
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
 	use Moo;
@@ -781,7 +781,7 @@ package Attean::Algebra::Service 0.033 {
 
 =cut
 
-package Attean::Algebra::Path 0.033 {
+package Attean::Algebra::Path 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -821,7 +821,7 @@ package Attean::Algebra::Path 0.033 {
 
 =cut
 
-package Attean::Algebra::Group 0.033 {
+package Attean::Algebra::Group 0.034 {
 	use utf8;
 	use Moo;
 	use Attean::API::Query;
@@ -891,7 +891,7 @@ package Attean::Algebra::Group 0.033 {
 
 =cut
 
-package Attean::Algebra::NegatedPropertySet 0.033 {
+package Attean::Algebra::NegatedPropertySet 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -947,7 +947,7 @@ package Attean::Algebra::NegatedPropertySet 0.033 {
 
 =cut
 
-package Attean::Algebra::PredicatePath 0.033 {
+package Attean::Algebra::PredicatePath 0.034 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf);
 	use namespace::clean;
@@ -980,7 +980,7 @@ package Attean::Algebra::PredicatePath 0.033 {
 
 =cut
 
-package Attean::Algebra::InversePath 0.033 {
+package Attean::Algebra::InversePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1022,7 +1022,7 @@ package Attean::Algebra::InversePath 0.033 {
 
 =cut
 
-package Attean::Algebra::SequencePath 0.033 {
+package Attean::Algebra::SequencePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1055,7 +1055,7 @@ package Attean::Algebra::SequencePath 0.033 {
 
 =cut
 
-package Attean::Algebra::AlternativePath 0.033 {
+package Attean::Algebra::AlternativePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1088,7 +1088,7 @@ package Attean::Algebra::AlternativePath 0.033 {
 
 =cut
 
-package Attean::Algebra::ZeroOrMorePath 0.033 {
+package Attean::Algebra::ZeroOrMorePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1129,7 +1129,7 @@ package Attean::Algebra::ZeroOrMorePath 0.033 {
 
 =cut
 
-package Attean::Algebra::OneOrMorePath 0.033 {
+package Attean::Algebra::OneOrMorePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1170,7 +1170,7 @@ package Attean::Algebra::OneOrMorePath 0.033 {
 
 =cut
 
-package Attean::Algebra::ZeroOrOnePath 0.033 {
+package Attean::Algebra::ZeroOrOnePath 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1211,7 +1211,7 @@ package Attean::Algebra::ZeroOrOnePath 0.033 {
 
 =cut
 
-package Attean::Algebra::Table 0.033 {
+package Attean::Algebra::Table 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1265,7 +1265,7 @@ package Attean::Algebra::Table 0.033 {
 
 =cut
 
-package Attean::Algebra::Ask 0.033 {
+package Attean::Algebra::Ask 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1283,7 +1283,7 @@ package Attean::Algebra::Ask 0.033 {
 
 =cut
 
-package Attean::Algebra::Construct 0.033 {
+package Attean::Algebra::Construct 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1308,7 +1308,7 @@ package Attean::Algebra::Construct 0.033 {
 
 =cut
 
-package Attean::Algebra::Describe 0.033 {
+package Attean::Algebra::Describe 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1329,7 +1329,7 @@ package Attean::Algebra::Describe 0.033 {
 
 =cut
 
-package Attean::Algebra::Load 0.033 {
+package Attean::Algebra::Load 0.034 {
 	use Moo;
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
@@ -1372,7 +1372,7 @@ package Attean::Algebra::Load 0.033 {
 
 =cut
 
-package Attean::Algebra::Clear 0.033 {
+package Attean::Algebra::Clear 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1426,7 +1426,7 @@ package Attean::Algebra::Clear 0.033 {
 
 =cut
 
-package Attean::Algebra::Create 0.033 {
+package Attean::Algebra::Create 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1461,7 +1461,7 @@ package Attean::Algebra::Create 0.033 {
 
 =cut
 
-package Attean::Algebra::Add 0.033 {
+package Attean::Algebra::Add 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
@@ -1519,12 +1519,12 @@ package Attean::Algebra::Add 0.033 {
 
 =cut
 
-package Attean::Algebra::Modify 0.033 {
+package Attean::Algebra::Modify 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use AtteanX::SPARQL::Constants;
 	use AtteanX::SPARQL::Token;
-	use List::MoreUtils qw(all any);
+	use List::Util qw(all any);
 	use Types::Standard qw(HashRef ArrayRef ConsumerOf);
 	use namespace::clean;
 	
