@@ -8,7 +8,7 @@ Attean::Plan - Representation of SPARQL query plan operators
 
 =head1 VERSION
 
-This document describes Attean::Plan version 0.033
+This document describes Attean::Plan version 0.034
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,7 @@ Evaluates a quad pattern against the model.
 
 =cut
 
-package Attean::Plan::Quad 0.033 {
+package Attean::Plan::Quad 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed reftype);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -139,9 +139,9 @@ Evaluates a join (natural-, anti-, or left-) using a nested loop.
 
 =cut
 
-package Attean::Plan::NestedLoopJoin 0.033 {
+package Attean::Plan::NestedLoopJoin 0.034 {
 	use Moo;
-	use List::MoreUtils qw(all);
+	use List::Util qw(all);
 	use namespace::clean;
 
 	with 'Attean::API::BindingSubstitutionPlan';
@@ -228,9 +228,9 @@ Evaluates a join (natural-, anti-, or left-) using a hash join.
 
 =cut
 
-package Attean::Plan::HashJoin 0.033 {
+package Attean::Plan::HashJoin 0.034 {
 	use Moo;
-	use List::MoreUtils qw(all);
+	use List::Util qw(all);
 	use namespace::clean;
 	
 	sub BUILD {
@@ -369,9 +369,9 @@ package Attean::Plan::HashJoin 0.033 {
 
 =cut
 
-package Attean::Plan::Construct 0.033 {
+package Attean::Plan::Construct 0.034 {
 	use Moo;
-	use List::MoreUtils qw(all);
+	use List::Util qw(all);
 	use Types::Standard qw(Str ArrayRef ConsumerOf InstanceOf);
 	use namespace::clean;
 	has 'triples' => (is => 'ro', 'isa' => ArrayRef[ConsumerOf['Attean::API::TripleOrQuadPattern']], required => 1);
@@ -480,10 +480,10 @@ package Attean::Plan::Construct 0.033 {
 
 =cut
 
-package Attean::Plan::Describe 0.033 {
+package Attean::Plan::Describe 0.034 {
 	use Moo;
 	use Attean::RDF;
-	use List::MoreUtils qw(all);
+	use List::Util qw(all);
 	use Types::Standard qw(Str ArrayRef ConsumerOf InstanceOf);
 	use namespace::clean;
 
@@ -566,7 +566,7 @@ named variable binding.
 
 =cut
 
-package Attean::Plan::EBVFilter 0.033 {
+package Attean::Plan::EBVFilter 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ConsumerOf);
@@ -625,7 +625,7 @@ ordering.
 
 =cut
 
-package Attean::Plan::Merge 0.033 {
+package Attean::Plan::Merge 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ArrayRef ConsumerOf);
@@ -654,7 +654,7 @@ Evaluates a set of sub-plans, returning the union of results.
 
 =cut
 
-package Attean::Plan::Union 0.033 {
+package Attean::Plan::Union 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
@@ -725,7 +725,7 @@ expressions, binding the produced values to new variables.
 
 =cut
 
-package Attean::Plan::Extend 0.033 {
+package Attean::Plan::Extend 0.034 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -736,7 +736,7 @@ package Attean::Plan::Extend 0.033 {
 	use Digest::SHA;
 	use Digest::MD5 qw(md5_hex);
 	use Scalar::Util qw(blessed looks_like_number);
-	use List::MoreUtils qw(uniq all);
+	use List::Util qw(uniq all);
 	use Types::Standard qw(ConsumerOf ArrayRef InstanceOf HashRef);
 	use namespace::clean;
 
@@ -1415,7 +1415,7 @@ hash of already-seen results.
 
 =cut
 
-package Attean::Plan::HashDistinct 0.033 {
+package Attean::Plan::HashDistinct 0.034 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1443,7 +1443,7 @@ filtering out sequential duplicates.
 
 =cut
 
-package Attean::Plan::Unique 0.033 {
+package Attean::Plan::Unique 0.034 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1478,7 +1478,7 @@ number of results ("offset") and limiting the total number of returned results
 
 =cut
 
-package Attean::Plan::Slice 0.033 {
+package Attean::Plan::Slice 0.034 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -1519,7 +1519,7 @@ of variable bindings in each result.
 
 =cut
 
-package Attean::Plan::Project 0.033 {
+package Attean::Plan::Project 0.034 {
 	use Moo;
 	with 'Attean::API::BindingSubstitutionPlan', 'Attean::API::UnaryQueryTree';
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1596,7 +1596,7 @@ sorting is applied.
 
 =cut
 
-package Attean::Plan::OrderBy 0.033 {
+package Attean::Plan::OrderBy 0.034 {
 	use Moo;
 	use Types::Standard qw(HashRef ArrayRef InstanceOf Bool Str);
 	use Scalar::Util qw(blessed);
@@ -1679,7 +1679,7 @@ Evaluates a SPARQL query against a remote endpoint.
 
 =cut
 
-package Attean::Plan::Service 0.033 {
+package Attean::Plan::Service 0.034 {
 	use Moo;
 	use Types::Standard qw(ConsumerOf Bool Str InstanceOf);
 	use Encode qw(encode);
@@ -1695,6 +1695,7 @@ package Attean::Plan::Service 0.033 {
 	has 'sparql' => (is => 'ro', isa => Str, required => 1);
 	has 'user_agent' => (is => 'rw', isa => InstanceOf['LWP::UserAgent']);
 	has 'request_signer' => (is => 'rw');
+	has 'client' => (is => 'rw', required => 0);
 
 	sub plan_as_string {
 		my $self	= shift;
@@ -1717,7 +1718,7 @@ package Attean::Plan::Service 0.033 {
 			request_signer	=> $self->request_signer,
 		);
 		$args{user_agent}	= $self->user_agent if ($self->user_agent);
-		my $client		= Attean::SPARQLClient->new(%args);
+		my $client		= $self->client || Attean::SPARQLClient->new(%args);
 		return sub {
 			return $client->query($sparql);
 		};
@@ -1730,7 +1731,7 @@ Returns a constant set of results.
 
 =cut
 
-package Attean::Plan::Table 0.033 {
+package Attean::Plan::Table 0.034 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -1795,7 +1796,7 @@ L<Attean::ListIterator>, the size of that iterator will be used.
 
 =cut
 
-package Attean::Plan::Iterator 0.033 {
+package Attean::Plan::Iterator 0.034 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf Int);
 	use namespace::clean;
@@ -1859,7 +1860,7 @@ package Attean::Plan::Iterator 0.033 {
 
 =cut
 
-package Attean::Plan::ALPPath 0.033 {
+package Attean::Plan::ALPPath 0.034 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -2011,7 +2012,7 @@ package Attean::Plan::ALPPath 0.033 {
 	}
 }
 
-package Attean::Plan::ZeroOrOnePath 0.033 {
+package Attean::Plan::ZeroOrOnePath 0.034 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -2110,7 +2111,7 @@ results were produced by evaluating the sub-plan.
 
 =cut
 
-package Attean::Plan::Exists 0.033 {
+package Attean::Plan::Exists 0.034 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -2144,7 +2145,7 @@ package Attean::Plan::Exists 0.033 {
 
 =cut
 
-package Attean::Plan::Aggregate 0.033 {
+package Attean::Plan::Aggregate 0.034 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -2154,7 +2155,7 @@ package Attean::Plan::Aggregate 0.033 {
 	use Digest::SHA;
 	use Digest::MD5 qw(md5_hex);
 	use Scalar::Util qw(blessed);
-	use List::MoreUtils qw(uniq);
+	use List::Util qw(uniq);
 	use Types::Standard qw(ConsumerOf InstanceOf HashRef ArrayRef);
 	use namespace::clean;
 
@@ -2493,7 +2494,7 @@ package Attean::Plan::Aggregate 0.033 {
 	}
 }
 
-package Attean::Plan::Sequence 0.033 {
+package Attean::Plan::Sequence 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2518,7 +2519,7 @@ package Attean::Plan::Sequence 0.033 {
 	}
 }
 
-package Attean::Plan::Clear 0.033 {
+package Attean::Plan::Clear 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2555,7 +2556,7 @@ package Attean::Plan::Clear 0.033 {
 	}
 }
 
-package Attean::Plan::Drop 0.033 {
+package Attean::Plan::Drop 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2590,7 +2591,7 @@ package Attean::Plan::Drop 0.033 {
 	}
 }
 
-package Attean::Plan::TripleTemplateToModelQuadMethod 0.033 {
+package Attean::Plan::TripleTemplateToModelQuadMethod 0.034 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf Str ArrayRef HashRef);
@@ -2666,7 +2667,7 @@ package Attean::Plan::TripleTemplateToModelQuadMethod 0.033 {
 	}
 }
 
-package Attean::Plan::Load 0.033 {
+package Attean::Plan::Load 0.034 {
 	use Moo;
 	use Encode;
 	use LWP::UserAgent;
@@ -2731,7 +2732,7 @@ package Attean::Plan::Unfold 0.032 {
 	use Digest::SHA;
 	use Digest::MD5 qw(md5_hex);
 	use Scalar::Util qw(blessed looks_like_number);
-	use List::MoreUtils qw(uniq all);
+	use List::Util qw(uniq all);
 	use Types::Standard qw(ConsumerOf ArrayRef InstanceOf HashRef);
 	use namespace::clean;
 
