@@ -4,7 +4,7 @@ AtteanX::Serializer::NTuples - Shared functionality for N-Triples and N-Quads se
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NTuples version 0.026
+This document describes AtteanX::Serializer::NTuples version 0.034
 
 =head1 SYNOPSIS
 
@@ -25,11 +25,11 @@ This document describes AtteanX::Serializer::NTuples version 0.026
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::NTuples 0.026 {
+package AtteanX::Serializer::NTuples 0.034 {
 	use Moo;
 	use Encode qw(encode);
 	use Attean::ListIterator;
-	use List::MoreUtils qw(any);
+	use List::Util qw(any);
 	use namespace::clean;
 	
 =item C<< serialize_iter_to_io( $fh, $iterator ) >>
@@ -86,7 +86,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
