@@ -4,7 +4,7 @@ AtteanX::Serializer::SPARQL - SPARQL Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::SPARQL version 0.028
+This document describes AtteanX::Serializer::SPARQL version 0.034
 
 =head1 SYNOPSIS
 
@@ -39,13 +39,13 @@ This document describes AtteanX::Serializer::SPARQL version 0.028
 use v5.14;
 use warnings;
 
-package AtteanX::Serializer::SPARQL 0.028 {
+package AtteanX::Serializer::SPARQL 0.034 {
 	use Moo;
 	use Data::Dumper;
 	use Encode qw(encode);
 	use Attean::ListIterator;
 	use Scalar::Util qw(blessed);
-	use List::MoreUtils qw(any);
+	use List::Util qw(any);
 	use AtteanX::SPARQL::Constants;
 	use namespace::clean;
 	with 'Attean::API::AbbreviatingSerializer';
@@ -287,7 +287,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2014--2020 Gregory Todd Williams. This
+Copyright (c) 2014--2022 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
